Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/dev G/C unnecessary IPL_HARDUSB



details:   https://anonhg.NetBSD.org/src/rev/e11595bc5bcd
branches:  trunk
changeset: 771656:e11595bc5bcd
user:      rmind <rmind%NetBSD.org@localhost>
date:      Sun Nov 27 14:36:20 2011 +0000

description:
G/C unnecessary IPL_HARDUSB

diffstat:

 sys/dev/ic/sl811hs.c          |  20 ++++++++++----------
 sys/dev/pcmcia/slhci_pcmcia.c |   6 +++---
 sys/dev/usb/usbdi.h           |   6 +-----
 3 files changed, 14 insertions(+), 18 deletions(-)

diffs (127 lines):

diff -r 93eaa6dc898b -r e11595bc5bcd sys/dev/pcmcia/slhci_pcmcia.c
--- a/sys/dev/pcmcia/slhci_pcmcia.c     Sun Nov 27 13:24:32 2011 +0000
+++ b/sys/dev/pcmcia/slhci_pcmcia.c     Sun Nov 27 14:36:20 2011 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: slhci_pcmcia.c,v 1.8 2011/03/08 04:58:21 kiyohara Exp $ */
+/* $NetBSD: slhci_pcmcia.c,v 1.9 2011/11/27 14:36:20 rmind Exp $ */
 /*
  * Not (c) 2007 Matthew Orgass
  * This file is public domain, meaning anyone can make any use of part or all 
@@ -11,7 +11,7 @@
 /* Glue for RATOC USB HOST CF+ Card (SL811HS chip) */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: slhci_pcmcia.c,v 1.8 2011/03/08 04:58:21 kiyohara Exp $");
+__KERNEL_RCSID(0, "$NetBSD: slhci_pcmcia.c,v 1.9 2011/11/27 14:36:20 rmind Exp $");
 
 #include <sys/param.h>
 #include <sys/device.h>
@@ -140,7 +140,7 @@
                 */
                slhci_preinit(sc, NULL, pioh->iot, pioh->ioh, 100, 2);
 
-               psc->sc_ih = pcmcia_intr_establish(pf, IPL_HARDUSB, 
+               psc->sc_ih = pcmcia_intr_establish(pf, IPL_USB,
                    slhci_intr, sc);
 
                if (psc->sc_ih == NULL) {
diff -r 93eaa6dc898b -r e11595bc5bcd sys/dev/usb/usbdi.h
--- a/sys/dev/usb/usbdi.h       Sun Nov 27 13:24:32 2011 +0000
+++ b/sys/dev/usb/usbdi.h       Sun Nov 27 14:36:20 2011 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: usbdi.h,v 1.79 2009/09/04 17:53:12 dyoung Exp $        */
+/*     $NetBSD: usbdi.h,v 1.80 2011/11/27 14:36:21 rmind Exp $ */
 /*     $FreeBSD: src/sys/dev/usb/usbdi.h,v 1.18 1999/11/17 22:33:49 n_hibma Exp $      */
 
 /*
@@ -273,13 +273,9 @@
 /* No match */
 #define UMATCH_NONE                                     0
 
-/* XXX Perhaps USB should have its own levels? */
 #define splusb splsoftnet
 #define splhardusb splbio
 #define IPL_USB IPL_BIO
-#define splsoftusb splusb
 #define IPL_SOFTUSB IPL_SOFTNET
-#define IPL_HARDUSB IPL_USB
-
 
 #endif /* _USBDI_H_ */



Home | Main Index | Thread Index | Old Index
diff -r 93eaa6dc898b -r e11595bc5bcd sys/dev/ic/sl811hs.c
--- a/sys/dev/ic/sl811hs.c      Sun Nov 27 13:24:32 2011 +0000
+++ b/sys/dev/ic/sl811hs.c      Sun Nov 27 14:36:20 2011 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: sl811hs.c,v 1.30 2011/10/17 13:06:08 isaki Exp $       */
+/*     $NetBSD: sl811hs.c,v 1.31 2011/11/27 14:36:20 rmind Exp $       */
 
 /*
  * Not (c) 2007 Matthew Orgass
@@ -84,7 +84,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: sl811hs.c,v 1.30 2011/10/17 13:06:08 isaki Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sl811hs.c,v 1.31 2011/11/27 14:36:20 rmind Exp $");
 
 #include "opt_slhci.h"
 
@@ -881,9 +881,9 @@
         * so start it first.
         */
 
        /* Start next is always done at splsoftusb, so we do this here so 
         * start functions are always called at softusb. XXX */
-       s = splsoftusb();
+       s = splusb();
        error = xfer->pipe->methods->start(SIMPLEQ_FIRST(&xfer->pipe->queue));
        splx(s);
 
@@ -1269,7 +1269,7 @@
 
 callback:
        xfer->status = USBD_CANCELLED;
        /* Abort happens at splsoftusb. */
        usb_transfer_complete(xfer);
 }
 
@@ -1382,7 +1382,7 @@
        usbd_status ret;
        int x, s;
 
-       x = splsoftusb(); 
+       x = splusb();
        s = splhardusb();
        simple_lock(&sc->sc_lock);
        ret = (*lcf)(sc, spipe, xfer);
@@ -1431,7 +1431,7 @@
 
        sc = (struct slhci_softc *)arg;
 
-       x = splsoftusb();
+       x = splusb();
        s = splhardusb();
        simple_lock(&sc->sc_lock);
        t = &sc->sc_transfers;
@@ -2328,8 +2328,8 @@
        }
 }
 
 /* slhci_callback is called after the lock is taken from splsoftusb.
  * s is pointer to old spl (splsoftusb). */
 static void
 slhci_callback(struct slhci_softc *sc, int *s)
 {
@@ -2495,7 +2495,7 @@
 }
 
 #if 0
 /* must be called with lock taken from splsoftusb */
 /* XXX static */ void
 slhci_pollxfer(struct slhci_softc *sc, struct usbd_xfer *xfer, int *s)
 {
@@ -881,9 +881,9 @@
         */
 
-       /* Start next is always done at splsoftusb, so we do this here so 
+       /* Start next is always done at splusb, so we do this here so 
         * start functions are always called at softusb. XXX */
@@ -1269,7 +1269,7 @@
 callback:
        xfer->status = USBD_CANCELLED;
-       /* Abort happens at splsoftusb. */
+       /* Abort happens at splusb. */
        usb_transfer_complete(xfer);
 }
@@ -2328,8 +2328,8 @@
 }
 
-/* slhci_callback is called after the lock is taken from splsoftusb.
- * s is pointer to old spl (splsoftusb). */
+/* slhci_callback is called after the lock is taken from splusb.
+ * s is pointer to old spl (splusb). */
 static void
 slhci_callback(struct slhci_softc *sc, int *s)
@@ -2495,7 +2495,7 @@
 
 #if 0
-/* must be called with lock taken from splsoftusb */
+/* must be called with lock taken from splusb */
 /* XXX static */ void
 slhci_pollxfer(struct slhci_softc *sc, struct usbd_xfer *xfer, int *s)